==> findbugs-maven-plugin-2.3.1-sources.jar: org/codehaus/mojo/findbugs/FindBugsGui.java <==
//
// Generated stub from file:/Users/garvin/NetBeansProjects/findbugs-maven-plugin/target/checkout/src/main/groovy/org/codehaus/mojo/findbugs/FindBugsGui.groovy
//

package org.codehaus.mojo.findbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import org.apache.maven.project.MavenProject;
import org.codehaus.groovy.maven.mojo.GroovyMojo;

/**
 * Launch the Findbugs GUI.
 * It will use all the parameters in the POM fle.
 *
 * @since 2.0
 * @goal gui
 * @description Launch the Findbugs GUI using the parameters in the POM fle.
 * @requiresDependencyResolution compile
 * @requiresProject
 * @author <a href="mailto:gleclaire@codehaus.org">Garvin LeClaire</a>
 * @version $Id: FindBugsGui.groovy gleclaire $
 */
public class FindBugsGui
    extends GroovyMojo
{
    /**
     * The name of the property resource bundle (Filesystem).
     */
    static final private java.lang.String BUNDLE_NAME = null;
    static final public java.lang.String getBUNDLE_NAME() {
        throw new InternalError("Stubbed method");
    }

    /**
     * The regex pattern to search for java class files.
     */
    static final private java.lang.String JAVA_REGEX_PATTERN = null;
    static final public java.lang.String getJAVA_REGEX_PATTERN() {
        throw new InternalError("Stubbed method");
    }

    /**
     * locale to use for Resource bundle.
     */
    static private Locale locale = null;
    static public Locale getLocale() {
        throw new InternalError("Stubbed method");
    }
    static public void setLocale(Locale value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Directory containing the class files for FindBugs to analyze.
     *
     * @parameter default-value="${project.build.outputDirectory}"
     * @required
     */
    private File classFilesDirectory = null;
    public File getClassFilesDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setClassFilesDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * turn on Findbugs debugging
     *
     * @parameter default-value="false"
     */
    private Boolean debug = null;
    public Boolean getDebug() {
        throw new InternalError("Stubbed method");
    }
    public void setDebug(Boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * List of artifacts this plugin depends on. Used for resolving the Findbugs coreplugin.
     *
     * @parameter expression="${plugin.artifacts}"
     * @required
     * @readonly
     */
    private ArrayList pluginArtifacts = null;
    public ArrayList getPluginArtifacts() {
        throw new InternalError("Stubbed method");
    }
    public void setPluginArtifacts(ArrayList value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Effort of the bug finders. Valid values are Min, Default and Max.
     *
     * @parameter default-value="Default"
     */
    private java.lang.String effort = null;
    public java.lang.String getEffort() {
        throw new InternalError("Stubbed method");
    }
    public void setEffort(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The plugin list to include in the report. This is a comma-delimited list.
     *
     * @parameter
     */
    private java.lang.String pluginList = null;
    public java.lang.String getPluginList() {
        throw new InternalError("Stubbed method");
    }
    public void setPluginList(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Maven Project
     *
     * @parameter expression="${project}"
     * @required
     * @readonly
     */
    private MavenProject project = null;
    public MavenProject getProject() {
        throw new InternalError("Stubbed method");
    }
    public void setProject(MavenProject value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Resource bundle for a specific locale.
     *
     * @parameter
     * @readonly
     */
    private ResourceBundle bundle = null;
    public ResourceBundle getBundle() {
        throw new InternalError("Stubbed method");
    }
    public void setBundle(ResourceBundle value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Specifies the directory where the findbugs native xml output will be generated.
     *
     * @parameter default-value="${project.build.directory}"
     * @required
     */
    private File findbugsXmlOutputDirectory = null;
    public File getFindbugsXmlOutputDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setFindbugsXmlOutputDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The file encoding to use when reading the source files. If the property <code>project.build.sourceEncoding</code>
     * is not set, the platform default encoding is used. <strong>Note:</strong> This parameter always overrides the
     * property <code>charset</code> from Checkstyle's <code>TreeWalker</code> module.
     *
     * @parameter expression="${encoding}" default-value="${project.build.sourceEncoding}"
     * @since 2.2
     */
    private java.lang.String encoding = null;
    public java.lang.String getEncoding() {
        throw new InternalError("Stubbed method");
    }
    public void setEncoding(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Maximum Java heap size in megabytes (default=512).
     *
     * @parameter default-value="512"
     * @since 2.2
     */
    private int maxHeap = 0;
    public int getMaxHeap() {
        throw new InternalError("Stubbed method");
    }
    public void setMaxHeap(int value) {
        throw new InternalError("Stubbed method");
    }

    public void execute() {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}

==> findbugs-maven-plugin-2.4.0-sources.jar: org/codehaus/mojo/findbugs/FindBugsGui.java <==
//
// Generated stub from file:/Users/garvin/NetBeansProjects/findbugs-maven-plugin/target/checkout/src/main/groovy/org/codehaus/mojo/findbugs/FindBugsGui.groovy
//

package org.codehaus.mojo.findbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import java.math.BigDecimal;
import java.math.BigInteger;
import org.apache.maven.project.MavenProject;
import org.codehaus.gmaven.mojo.GroovyMojo;

/**
 * Launch the Findbugs GUI.
 * It will use all the parameters in the POM fle.
 *
 * @since 2.0
 * @goal gui
 * @description Launch the Findbugs GUI using the parameters in the POM fle.
 * @requiresDependencyResolution compile
 * @requiresProject
 * @author <a href="mailto:gleclaire@codehaus.org">Garvin LeClaire</a>
 * @version $Id: FindBugsGui.groovy gleclaire $
 */
public class FindBugsGui
    extends GroovyMojo
    implements groovy.lang.GroovyObject
{
    /**
     * The name of the property resource bundle (Filesystem).
     */
    static final private java.lang.String BUNDLE_NAME = null;
    static final public java.lang.String getBUNDLE_NAME() {
        throw new InternalError("Stubbed method");
    }

    /**
     * The regex pattern to search for java class files.
     */
    static final private java.lang.String JAVA_REGEX_PATTERN = null;
    static final public java.lang.String getJAVA_REGEX_PATTERN() {
        throw new InternalError("Stubbed method");
    }

    /**
     * locale to use for Resource bundle.
     */
    static private Locale locale = null;
    static public Locale getLocale() {
        throw new InternalError("Stubbed method");
    }
    static public void setLocale(Locale value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Directory containing the class files for FindBugs to analyze.
     *
     * @parameter default-value="${project.build.outputDirectory}"
     * @required
     */
    private File classFilesDirectory = null;
    public File getClassFilesDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setClassFilesDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * turn on Findbugs debugging
     *
     * @parameter default-value="false"
     */
    private Boolean debug = null;
    public Boolean getDebug() {
        throw new InternalError("Stubbed method");
    }
    public void setDebug(Boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * List of artifacts this plugin depends on. Used for resolving the Findbugs coreplugin.
     *
     * @parameter expression="${plugin.artifacts}"
     * @required
     * @readonly
     */
    private ArrayList pluginArtifacts = null;
    public ArrayList getPluginArtifacts() {
        throw new InternalError("Stubbed method");
    }
    public void setPluginArtifacts(ArrayList value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Effort of the bug finders. Valid values are Min, Default and Max.
     *
     * @parameter default-value="Default"
     */
    private java.lang.String effort = null;
    public java.lang.String getEffort() {
        throw new InternalError("Stubbed method");
    }
    public void setEffort(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The plugin list to include in the report. This is a comma-delimited list.
     *
     * @parameter
     */
    private java.lang.String pluginList = null;
    public java.lang.String getPluginList() {
        throw new InternalError("Stubbed method");
    }
    public void setPluginList(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Maven Project
     *
     * @parameter expression="${project}"
     * @required
     * @readonly
     */
    private MavenProject project = null;
    public MavenProject getProject() {
        throw new InternalError("Stubbed method");
    }
    public void setProject(MavenProject value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Resource bundle for a specific locale.
     *
     * @parameter
     * @readonly
     */
    private ResourceBundle bundle = null;
    public ResourceBundle getBundle() {
        throw new InternalError("Stubbed method");
    }
    public void setBundle(ResourceBundle value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Specifies the directory where the findbugs native xml output will be generated.
     *
     * @parameter default-value="${project.build.directory}"
     * @required
     */
    private File findbugsXmlOutputDirectory = null;
    public File getFindbugsXmlOutputDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setFindbugsXmlOutputDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The file encoding to use when reading the source files. If the property <code>project.build.sourceEncoding</code>
     * is not set, the platform default encoding is used. <strong>Note:</strong> This parameter always overrides the
     * property <code>charset</code> from Checkstyle's <code>TreeWalker</code> module.
     *
     * @parameter expression="${encoding}" default-value="${project.build.sourceEncoding}"
     * @since 2.2
     */
    private java.lang.String encoding = null;
    public java.lang.String getEncoding() {
        throw new InternalError("Stubbed method");
    }
    public void setEncoding(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Maximum Java heap size in megabytes  (default=512).
     *
     * @parameter default-value="512"
     * @since 2.2
     */
    private int maxHeap = 0;
    public int getMaxHeap() {
        throw new InternalError("Stubbed method");
    }
    public void setMaxHeap(int value) {
        throw new InternalError("Stubbed method");
    }

    public void execute() {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}
